:mod:`bdbcontrib.predictors.multiple_regression`: Linear regression predictor
=============================================================================

Incorporating linear regression into BayesDB as a foreign predictor.

.. automodule:: bdbcontrib.predictors.multiple_regression
 :members:
